@@ -1,5 +1,4 @@
-#pragma once
-#include "time.h"
+#include "time.h"	//	2do: move this file to a util directory!
 
 	class CPerfTimer
 	{
@@ -7,6 +6,8 @@
 
 		CPerfTimer () : m_start (clock ()) {}
 
+		void Restart () { m_start  = clock () ; }
+
 		int GetTimeMS ()
 		{
 			return FormatTimeMS (clock ()) ;
@@ -18,10 +19,11 @@
 
 			if (CLOCKS_PER_SEC != 1000)
 				end = (clock_t) ((end  * 1000.0 / CLOCKS_PER_SEC)) ;
+
 			return int (end) ;
 			
 		}
-		
+
 	protected:
 		clock_t m_start ;
 	} ;
